@@ -4,9 +4,9 @@ Ddivergence<-function(CA=NULL, CB=NULL, n=10000){
      stop("matrices must be the same dimension and square")
   }
 
-  xi<-mvrnorm(n, rep(0,dim(CA)[1]), cov2cor(CA))
-  fx<-dmvnorm(xi, rep(0,dim(CA)[1]), cov2cor(CA))
-  gx<-dmvnorm(xi, rep(0,dim(CA)[1]), cov2cor(CB))
+  xi<-mvrnorm(n, rep(0,dim(CA)[1]), CA)
+  fx<-dmvnorm(xi, rep(0,dim(CA)[1]), CA)
+  gx<-dmvnorm(xi, rep(0,dim(CA)[1]), CB)
 
   mean(sqrt(0.5*((fx-gx)^2)/(fx+gx)))
 
